'use strict';

/**
 * @param {Egg.Application} app - egg application
 */
module.exports = app => {
  const { router, controller } = app;
  router.get('/', controller.home.index);

  // 网站数据接口
  router.get('/api/news/list', controller.news.list); // 新闻信息列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/news/fetch/:id', controller.news.fetch); // 获取新闻详情
  router.get('/api/site/config', controller.site.config_get); // 获取站点基本信息
  router.get('/api/site/content', controller.site.content); // 获取站点详细信息（关于我们、联系方式）
  router.get('/api/site/list', controller.site.list); // 获取分站列表
  router.get('/api/column/list', controller.column.list); // 栏目列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/column/fetch/:id', controller.column.fetch); // 获取栏目详情
  router.get('/api/menu/list', controller.menu.list); // 菜单列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/menu/fetch/:id', controller.menu.fetch); // 获取菜单详情

  router.get('/api/modules/list', controller.modules.list); // 模块列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/modules/fetch/:id', controller.modules.fetch); // 获取模块详情

  router.get('/api/newslist/list', controller.newslist.list); // 新闻信息列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/newslist/fetch/:id', controller.newslist.fetch); // 获取新闻信息详情

  router.get('/api/img/list', controller.img.list); // 图片信息列表，隐藏删除信息，按照置顶和时间排序
  router.get('/api/img/fetch/:id', controller.img.fetch); // 获取图片信息详情

  // 管理接口
  // 【分站】新闻接口
  router.get('/adminapi/news/query', controller.news.query); // 查询新闻信息
  router.get('/adminapi/news/fetch/:id', controller.news.fetch); // 获得新闻详情
  router.post('/adminapi/news/create', controller.news.create); // 发布新闻信息
  router.post('/adminapi/news/update/:id', controller.news.update); // 修改新闻信息
  router.post('/adminapi/news/delete/:id', controller.news.delete); // 删除新闻信息
  router.post('/adminapi/news/restore/:id', controller.news.restore); // 恢复新闻信息

  // 栏目接口
  // 【分站】栏目接口
  router.get('/adminapi/column/query', controller.column.query); // 查询栏目信息
  router.get('/adminapi/column/fetch/:id', controller.column.fetch); // 获得栏目详情
  router.post('/adminapi/column/create', controller.column.create); // 发布栏目信息
  router.post('/adminapi/column/update/:id', controller.column.update); // 修改栏目信息
  router.post('/adminapi/column/delete/:id', controller.column.delete); // 删除栏目信息
  router.post('/adminapi/column/restore/:id', controller.column.restore); // 恢复栏目信息

  // 菜单接口
  // 【分站】菜单接口
  router.get('/adminapi/menu/query', controller.menu.query); // 查询菜单信息
  router.get('/adminapi/menu/fetch/:id', controller.menu.fetch); // 获得菜单详情
  router.post('/adminapi/menu/create', controller.menu.create); // 发布菜单信息
  router.post('/adminapi/menu/update/:id', controller.menu.update); // 修改菜单信息
  router.post('/adminapi/menu/delete/:id', controller.menu.delete); // 删除菜单信息
  router.post('/adminapi/menu/restore/:id', controller.menu.restore); // 恢复菜单信息

  // 菜单列表接口
  // 【分站】菜单列表接口
  router.get('/adminapi/newslist/query', controller.newslist.query); // 查询菜单列表信息
  router.get('/adminapi/newslist/fetch/:id', controller.newslist.fetch); // 获得菜单列表详情
  router.post('/adminapi/newslist/create', controller.newslist.create); // 发布菜单列表信息
  router.post('/adminapi/newslist/update/:id', controller.newslist.update); // 修改菜单列表信息
  router.post('/adminapi/newslist/delete/:id', controller.newslist.delete); // 删除菜单列表信息
  router.post('/adminapi/newslist/restore/:id', controller.newslist.restore); // 恢复菜单列表信息

  // 模块接口
  // 【分站】模块接口
  router.get('/adminapi/modules/query', controller.modules.query); // 查询模块信息
  router.get('/adminapi/modules/fetch/:id', controller.modules.fetch); // 获得模块详情
  router.post('/adminapi/modules/create', controller.modules.create); // 发布模块信息
  router.post('/adminapi/modules/update/:id', controller.modules.update); // 修改模块信息
  router.post('/adminapi/modules/delete/:id', controller.modules.delete); // 删除模块信息
  router.post('/adminapi/modules/restore/:id', controller.modules.restore); // 恢复模块信息

  // 分站配置接口，用于分站管理员配置本分站信息
  router.get('/adminapi/site/config', controller.site.config_fetch); // 分站获取自身配置
  router.post('/adminapi/site/config', controller.site.config_set); // 分站配置自身
  // 系统管理员管理接口
  router.get('/adminapi/site/query', controller.site.query); // 查询分站信息
  router.get('/adminapi/site/fetch/:site', controller.site.fetch); // 获得分站详情
  router.post('/adminapi/site/create', controller.site.create); // 发布分站信息
  router.post('/adminapi/site/update/:site', controller.site.update); // 修改分站信息
  router.post('/adminapi/site/delete/:site', controller.site.delete); // 删除分站信息

  // 图片接口
  router.get('/adminapi/img/query', controller.img.query); // 查询图片信息
  router.get('/adminapi/img/fetch/:id', controller.img.fetch); // 获得图片详情
  router.post('/adminapi/img/create', controller.img.create); // 发布图片信息
  router.post('/adminapi/img/update/:id', controller.img.update); // 修改图片信息
  router.post('/adminapi/img/delete/:id', controller.img.delete); // 删除图片信息

  // 暂定为验证码测试接口
  router.get('/adminapi/verify/verify', controller.verify.verify); // 生成验证码并保存
  router.post('/adminapi/verify/check_verify', controller.verify.check_verify); // 检测验证码
  router.get('/adminapi/verify/sendmessage', controller.verify.sendmessage); // 发送手机验证码并保存
  router.post('/adminapi/verify/check_message', controller.verify.check_message); // 检测手机验证码


  router.get('/adminapi/verify/creeper', controller.verify.creeper); // 测试爬虫
  // http://127.0.0.1:8105/adminapi/verify/creeper
};
